# Oups, I did it again

Une erreur inattendue s'est produite. Voulez-vous envoyer un rapport de bogue ? Cette action est automatique et aide à prévenir des problèmes similaires dans l'avenir.

[Envoyer le rapport de bogue](opensesame://event.bug_report_send){: .important-button}

Vie privée :

- Le message d'erreur (voir au-dessous) peut contenir des informations identifiables, comme votre nom d'utilisateur. Dans ce cas, cette information sera utilisée seulement pour corriger des bogues.

Information :

- Operating System: %(platform)s
- OpenSesame: %(version)s
- Python: %(python_version)s

Ne plus montrer ce message !

- Si vous ne voulez plus voir les messages d'erreur dans l'avenir, vous pouvez désactiver l'extension bug_report sous Menu → Outils → Gestionnaire plug-ins et extensions. Cela ne résout pas automatiquement le problème -- il supprime simplement le rapport.

Message d'erreur :

%(traceback)s
